@@ -1,5 +1,5 @@
 package App::Provision::Mysql;
-$App::Provision::Mysql::VERSION = '0.01';
+$App::Provision::Mysql::VERSION = '0.02';
 BEGIN {
   $App::Provision::Mysql::AUTHORITY = 'cpan:GENE';
 }
@@ -10,9 +10,18 @@ use parent qw( App::Provision::Tiny );
 sub mysql
 {
     my $self = shift;
-    $self->recipe(
-      [qw( brew install mysql )],
-    );
+    if ( $self->{system} eq 'osx' )
+    {
+        $self->recipe(
+          [qw( brew install mysql )],
+        );
+    }
+    elsif ( $self->{system} eq 'apt' )
+    {
+        $self->recipe(
+          [qw( sudo apt-get install mysql )],
+        );
+    }
 }
 
 1;
@@ -29,7 +38,7 @@ App::Provision::Mysql
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 AUTHOR
 
